@@ -38,6 +38,7 @@ class Core(CoreCache, CoreGetters):
         self._dirs_boards = [
             join(dirname(__file__), "..", "..", "..", "..", "boards"),
             join(self._dir_base, "boards"),
+            "boards",
         ]
         self._dirs_shapes = [
             join(self._dir_base, "shapes"),
@@ -209,6 +210,8 @@ class Core(CoreCache, CoreGetters):
         board = Board(**manifest)
         pcb = board.pcb
 
+        if not pcb:
+            return board
         pcb.vars["NAME"] = board.build.variant
         pcb.vars["TITLE"] = board.name
         pcb.vars["SYMBOL"] = pcb.symbol
