@@ -24,21 +24,25 @@ class FlashRegion(Model):
     @property
     def start_hex(self) -> str:
         if not self.hex_offs_len:
-            return hex(self.start).upper()
-        return f"0x%0{self.hex_offs_len}x" % self.start
+            return "0x%X" % self.start
+        return f"0x%0{self.hex_offs_len}X" % self.start
 
     @property
     def end_hex(self) -> str:
         if not self.hex_offs_len:
-            return hex(self.end).upper()
-        return f"0x%0{self.hex_offs_len}x" % self.end
+            return "0x%X" % self.end
+        return f"0x%0{self.hex_offs_len}X" % self.end
 
     @property
     def length_hex(self) -> str:
         if not self.hex_size_len:
-            return hex(self.length).upper()
-        return f"0x%0{self.hex_size_len}x" % self.length
+            return "0x%X" % self.length
+        return f"0x%0{self.hex_size_len}X" % self.length
 
     @property
     def length_str(self) -> str:
         return sizeof(self.length)
+
+    @property
+    def lst(self) -> list[str]:
+        return [self.start_hex, self.length_str + " / " + self.length_hex, self.end_hex]
